@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         bible.c
-* RCS:          $Header: bible.c,v 1.19 93/04/26 11:17:27 chip Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/bible.c,v 2.1 2003/01/08 15:50:53 matthew Exp $
 * Description:  Write Bible text to stdout.
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Jan 21 1989
@@ -41,7 +41,13 @@
 *  Added interactive command processing and concordance.
 *******************************************************************************
 *
-* $Log:	bible.c,v $
+* $Log: bible.c,v $
+* Revision 2.1  2003/01/08 15:50:53  matthew
+* applied debian patch
+*
+* Revision 2.0  2003/01/08 15:29:51  matthew
+* versions collected from the net
+*
  * Revision 1.19  93/04/26  11:17:27  11:17:27  chip (Chip Chapin)
  * Release 4.00
  * Public release of portable datafile version.
@@ -137,6 +143,7 @@
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <readline/readline.h>
 #include "tsl.h"
 #include "brl.h"
 #include "version.h"
@@ -149,7 +156,7 @@
 #define LINESZ 1024
 #define VBUFFSZ 32768
 
-static char rcs_ident[]="@(#)$Header: bible.c,v 1.19 93/04/26 11:17:27 chip Exp $";
+static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/bible.c,v 2.1 2003/01/08 15:50:53 matthew Exp $";
 
 
 char *myname;			/* Program Name */
@@ -812,27 +819,29 @@ char *cmd;
 
 
 
-prompter()
+char *getprompt()
 /*----------------------------------------------------------------------
 |   NAME:
-|       prompter
+|       getprompt
 |
 |   ALGORITHM:
-|       Display prompt for interactive user.
+|       Get prompt for interactive user.
 |
 |   HISTORY:
 |       921224 cc Initial creation.
+|       020707 dm Change prompter to getprompt for readline.
 |
 \*----------------------------------------------------------------------*/
 
 {
     char vbuf[REFSZ];
+    static char promptbuf[LINESZ];
     
-    printf( "%s(%s) [%s]%s ", myname,
+    sprintf(promptbuf, "%s(%s) [%s]%s ", myname,
 	   brl_textname, brl_num_to_ref(vbuf, &brl_cur_vnum),
 	   (skip_inc > 0 ? ">" : "<") );	
-    fflush( stdout );
-} /* prompter */
+    return promptbuf;
+} /* getprompt */
 
 
 
@@ -890,7 +899,7 @@ main(argc, argv)
 int argc;
 char **argv;
 {
-  char line[VSPECSZ];
+  char *line;
   char *dfname, *dfpath, *s;
   char ch;
 
@@ -977,11 +986,12 @@ char **argv;
       /* read from stdin */
       printf( "%s: %s\n", myname, release_version );
       printf( "Hit '?' for help.\n" );
+      rl_bind_key('\t', rl_insert);
       brl_printverse( "Gen1:1", pretty_printing, line_width, outf );
-      prompter();
-      while(fgets(line, VSPECSZ, stdin) != NULL) {
+      while((line = readline(getprompt())) != NULL) {
 	  user_input( line );
-	  prompter();
+	  if (*line != '\0') add_history(line);
+	  free(line);
       }
       printf( "\n" );
   }
