@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         brl.c
-* RCS:          $Header: brl.c,v 1.16 93/04/26 11:18:12 chip Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/brl.c,v 2.1 2003/01/08 15:50:53 matthew Exp $
 * Description:  Bible Retrieval Library
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Jan 14 1989, Chip Chapin
@@ -15,6 +15,9 @@
 *
 * Revisions:
 *
+* Thu Dec 30 1999 (Oliver Elphick) olly@lfix.co.uk
+*  Increase VBSIZE from 512 to 550, because very long verses were
+*  being truncated in pretty printing.
 * Thu Apr 22 14:39:43 1993 (Chip Chapin) chip@hpclbis
 *  Fix bad return value from brl_printverse when no errors occurred.
 *  Support non-POSIX sprintf.
@@ -36,7 +39,13 @@
 *  Added brl_num_to_ref to support concordance.
 *******************************************************************************
 *
-* $Log:	brl.c,v $
+* $Log: brl.c,v $
+* Revision 2.1  2003/01/08 15:50:53  matthew
+* applied debian patch
+*
+* Revision 2.0  2003/01/08 15:29:52  matthew
+* versions collected from the net
+*
  * Revision 1.16  93/04/26  11:18:12  11:18:12  chip (Chip Chapin)
  * Release 4.00
  * Public release of portable datafile version.
@@ -148,7 +157,7 @@
 
 #define FALSE	(0)
 
-static char rcs_ident[]="@(#)$Header: brl.c,v 1.16 93/04/26 11:18:12 chip Exp $";
+static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/brl.c,v 2.1 2003/01/08 15:50:53 matthew Exp $";
 
 char *booknamestr[] = { "Genesis",
 			   "Exodus",
@@ -553,6 +562,7 @@ int book;
 		    /* phili, philp, phil, phi, ph, php, pp, etc. */
 		    /* This gives preference to Philippians over Philemon */
 		    book = (int)PHILIP;
+			 if (!isalpha(c)) *s1--; /* point back to the chapter number */
 		} else if (c == 'e' || c == 'm') book = (int)PHILEM;
 		else {
 		    tsl_error( FALSE, BADBOOK, *s );
@@ -604,7 +614,7 @@ int book;
 
 
 
-int verse_continuation( s, book, chapter, absverse )
+int verse_continuation( s, book, chapter, verse, absverse )
 /*----------------------------------------------------------------------
 |   NAME:
 |       verse_continuation
@@ -634,11 +644,10 @@ int verse_continuation( s, book, chapter, absverse )
 \*----------------------------------------------------------------------*/
 
 char **s;
-int book, chapter;
+int book, chapter, verse;
 ref_t absverse;
 {
     int	n;
-    int verse;
     char *s1;
 
     s1 = *s;	/* For easier handling.  Be sure to update it */
@@ -646,12 +655,19 @@ ref_t absverse;
 
     if (*s1++ == '-') {
 	/* yup, there's a continuation */
-	if (verse_id( &s1, &book, &chapter, &verse ) == 0)
-	    return 0;
-	*s = s1;
+	get_nonblank(s1);
+	if (*s1 == '\0') {
+	    /* special case - end of chapter */
+	    n = verse_num( book, chapter, 1000);
+	    *s = s1;
+	} else {
+	    if (verse_id( &s1, &book, &chapter, &verse ) == 0)
+		return 0;
+	    *s = s1;
 
-	/* Determine absolute verse number of ending verse */
-	n = verse_num( book, chapter, verse );
+	    /* Determine absolute verse number of ending verse */
+	    n = verse_num( book, chapter, verse );
+	}
 
 	/* how many verses is that? */
 	n = n - absverse +1;
@@ -906,7 +922,7 @@ int	*n;
     if ((av = verse_id( &(*s), &book, &chapter, &verse )) == 0)
 	return 0;
     if (**s) {
-	if ((*n = verse_continuation( &(*s), book, chapter, av )) == 0)
+	if ((*n = verse_continuation( &(*s), book, chapter, verse, av )) == 0)
 	    return 0;
     } else {
 	*n = 1;
@@ -977,6 +993,7 @@ ref_t brl_printverse( vs, pretty, lwidth, outf )
 |       921223 cc Print chapter heading anytime v.1 is printed.
 |       930105 cc Added outf functionality & return verse number.
 |       930422 cc Return correct versenum when errors occur.
+|       991230 oe Increase VBSIZE to avoid verse truncation.
 |
 \*----------------------------------------------------------------------*/
 
@@ -988,7 +1005,8 @@ FILE *outf;
     ref_t vn, vref;
     int vc, vcount;
     int len, indent, i;
-#define VBSIZE 512
+/* Length of the longest line is 535, so original length of 512 was not enough */
+#define VBSIZE 550
     char vb1[VBSIZE], vb2[VBSIZE];
     char *srcp, *dstp, *endp;
     int  curbook, curchapter, curverse;
@@ -1143,7 +1161,7 @@ char *dfname, *dfpath;
     if (dfname == NULL)
 	dfname = "bible.data";
     if (dfpath == NULL)
-	dfpath = "./ " DESTLIB "/"; /* /usr/local/lib/; */
+	dfpath = "./ " DESTLIB "/"; /* /usr/lib/; */
     tsl_init( dfname, dfpath, memlimit );
 
     /* Set (low) illegal value for current context.
