@@ -2,7 +2,7 @@
 *******************************************************************************
 *
 * File:         tsl.c
-* RCS:          $Header: tsl.c,v 1.9 93/04/26 11:18:14 chip Exp $
+* RCS:          $Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.4 2003/07/26 09:25:05 matthew Exp $
 * Description:  Text Storage Library
 * Author:       Chip Chapin, Hewlett Packard Company
 * Created:      Thu Aug 24 15:37:16 1989
@@ -31,7 +31,22 @@
 * Mon Dec 21 13:40:54 1992 (Chip Chapin) chip@hpclbis
 *  Made findfile a separate function in util.c
 *******************************************************************************
-* $Log:	tsl.c,v $
+* $Log: tsl.c,v $
+* Revision 2.4  2003/07/26 09:25:05  matthew
+* Move tsl_error declaration to tsl.h
+*
+* Revision 2.3  2003/07/26 09:18:06  matthew
+* use starg.h-style variable arguments. Also use gccs format checking
+*
+* Revision 2.2  2003/01/08 19:10:24  matthew
+* correct the .win assignments to be 0 not null, since they are ints not pointers
+*
+* Revision 2.1  2003/01/08 15:50:53  matthew
+* applied debian patch
+*
+* Revision 2.0  2003/01/08 15:29:52  matthew
+* versions collected from the net
+*
  * Revision 1.9  93/04/26  11:18:14  11:18:14  chip (Chip Chapin)
  * Release 4.00
  * Public release of portable datafile version.
@@ -95,7 +110,7 @@
 \*----------------------------------------------------------------------*/
 
 #include <stdio.h>
-#include <varargs.h>
+#include <stdarg.h>
 /* #include <search.h> */
 #include "tsl.h"
 
@@ -107,7 +122,7 @@
 #define FALSE	(0)
 #define TRUE	(1)
 
-static char rcs_ident[]="@(#)$Header: tsl.c,v 1.9 93/04/26 11:18:14 chip Exp $";
+static char rcs_ident[]="@(#)$Header: /home/matthew/cvs/bible-kjv-4.10/tsl.c,v 2.4 2003/07/26 09:25:05 matthew Exp $";
 
 char *malloc();
 char *strtok();
@@ -117,7 +132,7 @@ FILE *cfp;			/* Concordance data file pointer */
 struct tsl_conc_fileheader cfh;	/* Concordance file header */
 char *cf_words;			/* Concordance string (word) buffer */
 short int *cf_index;		/* Concordance index */
-long tsl_wsize;			/* Window size (bytes) */
+int tsl_wsize;			/* Window size (bytes) */
 int tsl_wnum;			/* Number of windows */
 file_ptr_t *tsl_wtable=NULL;	/* Table of window offsets in data file */
 
@@ -144,8 +159,7 @@ int tsl_maxbuffs;		/* Maximum number of buffers we're allowed */
 int tsl_maxbuffusage=0x100000;	/* Max buffer mem usage (bytes)	 */
 
 
-
-tsl_error( fatal, va_alist )
+void tsl_error(int fatal, const char *format, ...)
 /*----------------------------------------------------------------------
 |   NAME:
 |       tsl_error
@@ -161,16 +175,11 @@ tsl_error( fatal, va_alist )
 |       890904 cc Created.
 |
 \*----------------------------------------------------------------------*/
-
-int fatal;
-va_dcl
 {
     va_list ap;
-    char *format;
 
-    va_start(ap);
+    va_start(ap, format);
 
-    format = va_arg(ap, char *);
     vfprintf(stderr, format, ap);
     putc('\n', stderr);
 
@@ -248,7 +257,7 @@ ref_t range_end;
 	   negated and put in the word's index entry.
 	 */
 	*sbuf = -rsize;
-	if (range_start <= *sbuf && *sbuf <= range_end)
+	if (!range_start || (range_start <= *sbuf && *sbuf <= range_end))
 	    return( 1 );
 	else
 	    return( 0 );
@@ -256,7 +265,7 @@ ref_t range_end;
     
     /* Read all the refs for this word */
     /* Where do they end? */
-    fseek( cfp, (long)(inx_start + univ2int(cfh.data_ptr)), SEEK_SET );
+    fseek( cfp, (int)(inx_start + univ2int(cfh.data_ptr)), SEEK_SET );
     fread( tbuf, 1, rsize, cfp );
 
     /* Process the ref list.
@@ -343,7 +352,7 @@ int vn, vc;
 char *vb;
 int vbsize;
 {
-    long vstart, vsize;
+    int vstart, vsize;
     
     vstart = line_locator[vn];
     vsize = line_locator[ vn+vc ] - vstart;
@@ -372,7 +381,7 @@ int tsl_printtext( vn, vc )
 
 int vn, vc;
 {
-    long vstart, vsize;
+    int vstart, vsize;
     
     vstart = line_locator[vn];
     vsize = line_locator[ vn+vc ] - vstart;
@@ -405,12 +414,12 @@ tsl_textread( start, vsize, vb )
 |
 \*----------------------------------------------------------------------*/
 
-long start, vsize;
+int start, vsize;
 char *vb;
 {
 #ifdef PLAINTEXT
     /* here's the version that works with a plain text file */
-    if (fseek( tfp, (long)start, 0 ) == EOF) {
+    if (fseek( tfp, (int)start, 0 ) == EOF) {
 	tsl_error( TRUE, "Cannot seek" );
     } 
     else {
@@ -427,15 +436,15 @@ char *vb;
        file, and how big it is.  Read the compressed window and uncompress it.
        Now we can locate the start of the text and return it.
        */
-    long window;			/* current window number */
-    long bstart;			/* starting byte relative to beginning
+    int window;			/* current window number */
+    int bstart;			/* starting byte relative to beginning
 					   of uncompressed window */
     file_ptr_t wstart;			/* starting position of compressed
 					   window within the data file */
-    long cmpwsize;			/* size of compressed window within the
+    int cmpwsize;			/* size of compressed window within the
 					   data file */
-    long bytes_remaining;		/* Number of bytes yet to be done */
-    long size;				/* bytes needed from current window */
+    int bytes_remaining;		/* Number of bytes yet to be done */
+    int size;				/* bytes needed from current window */
     char *uncbuf;			/* buffer for uncompressed data */
     struct buffer_rec *brp;		/* current buffer rec */
     char *cp, *ep;			/* Handy pointers */
@@ -477,7 +486,7 @@ char *vb;
 	    wstart   = tsl_wtable[window];	/* window start in file */
 	    cmpwsize = tsl_wtable[window+1]
 		- wstart;			/*Size of compressed window*/
-	    if (fseek( tfp, (long)wstart, 0 ) == EOF) {
+	    if (fseek( tfp, (int)wstart, 0 ) == EOF) {
 		tsl_error( TRUE, "Bad seek" );
 	    } 
 	    if (cmpwsize > tsl_wsize) {
@@ -609,7 +618,7 @@ int  memlimit;
     if (!fread( tsl_wtable, tablesize, 1, tfp )) {
 	tsl_error( TRUE, "Error reading data file %s", dfname );
     }
-    /* Convert Univ_Ints in window table to regular longs */
+    /* Convert Univ_Ints in window table to regular ints */
     up = (Univ_Int *) tsl_wtable;
     for (i=0; i<=tsl_wnum; i++) {
 	tsl_wtable[i] = (file_ptr_t) univ2int( *up++ );
@@ -626,11 +635,11 @@ int  memlimit;
     if (tsl_maxbuffs < 1) tsl_maxbuffs = 1;
     tsl_firstbuffer.next = &tsl_lastbuffer;
     tsl_firstbuffer.prev = NULL;
-    tsl_firstbuffer.win  = NULL;
+    tsl_firstbuffer.win  = 0;
     tsl_firstbuffer.bufferp = NULL;
     tsl_lastbuffer.prev = &tsl_firstbuffer;
     tsl_lastbuffer.next = NULL;
-    tsl_lastbuffer.win  = NULL;
+    tsl_lastbuffer.win  = 0;
     tsl_lastbuffer.bufferp = NULL;
 
     /* Global buffer for compressed text.  Much bigger than needed. :-) */
